@@ -1,19 +1,18 @@
-
 #' @title Dropdown Button
 #'
 #' @description
-#' Create a dropdown menu
+#' Create a dropdown menu with Bootstrap
 #'
 #' @param ... List of tag to be displayed into the dropdown menu.
 #' @param circle Logical. Use a circle button
 #' @param icon An icon to appear on the button.
-#' @param status Color of the button.
+#' @param status Color, must be a valid Bootstrap status : default, primary, info, success, warning, danger.
 #' @param size Size of the button : default, lg, sm, xs.
-#' @param label Label to appear on the button. If circle = TRUE and tooltip = TRUE, label is used in tooltip
-#' @param tooltip Put a tooltip on the button
-#' @param right The dropdown menu starts on the right
-#' @param up Display the dropdown menu above
-#' @param width Width of the dropdown menu
+#' @param label Label to appear on the button. If circle = TRUE and tooltip = TRUE, label is used in tooltip.
+#' @param tooltip Put a tooltip on the button, you can customize tooltip with \code{tooltipOptions}.
+#' @param right Logical. The dropdown menu starts on the right.
+#' @param up Logical. Display the dropdown menu above.
+#' @param width Width of the dropdown menu content.
 #'
 #'
 #' @import shiny
@@ -33,18 +32,23 @@
 #'
 #' }
 #' }
-#'
+
 
 
 dropdownButton <- function(..., circle = TRUE, status = "default", size = "default", icon = NULL,
                            label = NULL, tooltip = FALSE, right = FALSE, up = FALSE, width = NULL) {
 
-  status <- match.arg(arg = status, choices = c("default", "primary", "success", "info", "warning", "danger"))
+  status <- match.arg(
+    arg = status,
+    choices = c("default", "primary", "success", "info", "warning", "danger")
+  )
+  size <- match.arg(arg = size, choices = c("default", "lg", "sm", "xs"))
   buttonID <- paste0("drop", sample.int(1e9, 1))
 
   # dropdown content
   html_ul <- list(
     class = paste("dropdown-menu", ifelse(right, "dropdown-menu-right", "")),
+    class = "dropdown-shinyWidgets",
     id = paste("dropdown-menu", buttonID, sep = "-"),
     style = if (!is.null(width))
       paste0("width: ", validateCssUnit(width), ";"),
@@ -56,14 +60,18 @@ dropdownButton <- function(..., circle = TRUE, status = "default", size = "defau
   if (circle) {
     html_button <- circleButton(
       inputId = buttonID, icon = icon, status = status, size = size,
-      class = "dropdown-toggle", `data-toggle` = "dropdown"
+      class = "dropdown-toggle",
+      # onclick = paste0("$(this).parent().toggleClass('open');")
+      `data-toggle` = "dropdown"
     )
   } else {
     html_button <- list(
-      class = paste0("btn btn-", status," dropdown-toggle ", ifelse(size == "default", "", paste0("btn-", size))),
+      class = paste0("btn btn-", status," dropdown-toggle "),
+      class = if (size == "default") paste0("btn-", size),
       type = "button",
       id = buttonID,
       `data-toggle` = "dropdown",
+      # onclick = paste0("$(this).parent().toggleClass('open');"),
       `aria-haspopup` = "true",
       `aria-expanded` = "true",
       list(icon, label),
@@ -84,28 +92,24 @@ dropdownButton <- function(..., circle = TRUE, status = "default", size = "defau
         "false"
       else x
     })
-    js_tooltip <- tags$script(
-      # whisker::whisker.render(
-      #   template = "$('#{{buttonID}}').tooltip({ placement: '{{{placement}}}', title: '{{{title}}}', html: {{{html}}} });",
-      #   data = list(buttonID = buttonID, placement = tooltip$placement,
-      #               title = tooltip$title, html = tooltip$html)
-      # )
+    tooltipJs <- tags$script(
       sprintf(
         "$('#%s').tooltip({ placement: '%s', title: '%s', html: %s });",
         buttonID, tooltip$placement, tooltip$title, tooltip$html
       )
     )
   } else {
-    js_tooltip <- ""
+    tooltipJs <- ""
   }
 
-  tags$div(
+  dropdownTag <- tags$div(
     class = ifelse(up, "dropup", "dropdown"),
     html_button,
     do.call(tags$ul, html_ul),
-    tags$script(paste0("$('#", paste("dropdown-menu", buttonID, sep = "-"), "').click(function(e) {e.stopPropagation();});")),
-    js_tooltip
+    # tags$script(paste0("$('#", paste("dropdown-menu", buttonID, sep = "-"), "').click(function(e) {e.stopPropagation();});")),
+    tooltipJs
   )
+  attachShinyWidgetsDep(dropdownTag, "dropdown")
 }
 
 
@@ -116,7 +120,7 @@ dropdownButton <- function(..., circle = TRUE, status = "default", size = "defau
 #'
 #' @param placement Placement of tooltip : right, top, bottom, left.
 #' @param title Text of the tooltip
-#' @param html Logical.
+#' @param html Logical, allow HTML tags inside tooltip
 #'
 #'
 #' @export
